@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : databases/lib/libipv6calc_db_wrapper_IP2Location.c
- * Version    : $Id: libipv6calc_db_wrapper_IP2Location.c,v 1.38 2015/07/09 20:38:34 ds6peter Exp $
- * Copyright  : 2013-2015 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: 77389c33d2edb23d29c2f68a0d489d6f3ce5fcb3 $
+ * Copyright  : 2013-2016 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  ipv6calc IP2Location database wrapper
@@ -72,11 +72,9 @@ static int dl_status_IP2Location_free_record = IPV6CALC_DL_STATUS_UNKNOWN;
 typedef IP2LocationRecord *(*dl_IP2Location_free_record_t)(IP2LocationRecord *record);
 static union { dl_IP2Location_free_record_t func; void * obj; } dl_IP2Location_free_record;
 
-/*
 static int dl_status_IP2Location_api_version_num = IPV6CALC_DL_STATUS_UNKNOWN;
 typedef unsigned long int (*dl_IP2Location_api_version_num_t)(void);
 static union { dl_IP2Location_api_version_num_t func; void * obj; } dl_IP2Location_api_version_num;
-*/
 
 static int dl_status_IP2Location_api_version_string = IPV6CALC_DL_STATUS_UNKNOWN;
 typedef char *(*dl_IP2Location_api_version_string_t)(void);
@@ -100,7 +98,7 @@ static int ip2location_db_region_city_v4 = 0;
 static int ip2location_db_region_city_v6 = 0;
 
 typedef struct {
-	int num;
+	unsigned int num;
 	int dbtype;
 	int dbym;
 } s_ipv6calc_ip2location_db;
@@ -183,8 +181,8 @@ char ip2location_db_usage_string[NI_MAXHOST] = "";
 static IP2Location *db_ptr_cache[MAXENTRIES_ARRAY(libipv6calc_db_wrapper_IP2Location_db_file_desc)];
 
 // local prototyping
-static char     *libipv6calc_db_wrapper_IP2Location_dbfilename(const int type); 
-static int       libipv6calc_db_wrapper_IP2Location_db_compatible(const int type); 
+static char     *libipv6calc_db_wrapper_IP2Location_dbfilename(const unsigned int type); 
+static int       libipv6calc_db_wrapper_IP2Location_db_compatible(const unsigned int type); 
 
 
 /*
@@ -780,12 +778,12 @@ void libipv6calc_db_wrapper_IP2Location_wrapper_print_db_info(const int level_ve
  * wrapper: string regarding used database infos
  */
 char *libipv6calc_db_wrapper_IP2Location_wrapper_db_info_used(void) {
-	int db;
+	unsigned int db;
 	IP2Location *loc;
 	char tempstring[NI_MAXHOST];
 	char *info;
 
-	int db_lite_used = 0;
+	unsigned int db_lite_used = 0;
 
 	for (db = 0; db < 32 * IP2LOCATION_DB_MAX_BLOCKS_32; db++) {
 		if ((ip2location_db_usage_map[db / 32] & (1 << (db % 32))) != 0) {
@@ -883,6 +881,36 @@ char *libipv6calc_db_wrapper_IP2Location_lib_version(void) {
 		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Previous call of dlsym already successful: %s", dl_symbol);
 	};
 
+
+	const char *dl_symbol2 = "IP2Location_api_version_num";
+
+	if (dl_IP2Location_handle == NULL) {
+		snprintf(result_IP2Location_lib_version, sizeof(result_IP2Location_lib_version), "LIBRARY-NOT-LOADED");
+		goto END_libipv6calc_db_wrapper;
+	};
+
+	if (dl_status_IP2Location_api_version_num == IPV6CALC_DL_STATUS_UNKNOWN) {
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Call dlsym: %s", dl_symbol2);
+
+		dlerror();    /* Clear any existing error */
+
+		*(void **) (&dl_IP2Location_api_version_num.obj) = dlsym(dl_IP2Location_handle, dl_symbol2);
+
+		if ((error = dlerror()) != NULL)  {
+			dl_status_IP2Location_api_version_num = IPV6CALC_DL_STATUS_ERROR;
+		} else {
+			dl_status_IP2Location_api_version_num = IPV6CALC_DL_STATUS_OK;
+			DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Called dlsym successful: %s", dl_symbol2);
+		};
+	} else if (dl_status_IP2Location_api_version_num == IPV6CALC_DL_STATUS_ERROR) {
+		/* already known issue */
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Previous call of dlsym already failed: %s", dl_symbol2);
+	} else {
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Previous call of dlsym already successful: %s", dl_symbol2);
+	};
+
+
+
 	if (ip2location_ipv6_compat == 0) {
 		if (dl_status_IP2Location_api_version_string == IPV6CALC_DL_STATUS_OK) {
 			// take use of new (>= 7.0.1) function
@@ -895,8 +923,12 @@ char *libipv6calc_db_wrapper_IP2Location_lib_version(void) {
 		snprintf(result_IP2Location_lib_version, sizeof(result_IP2Location_lib_version), "API<7.0.0 Major=%d", libipv6calc_db_wrapper_IP2Location_library_version_major());
 	};
 
+#else
+#ifdef SUPPORT_IP2LOCATION_API_VERSION_STRING
+	snprintf(result_IP2Location_lib_version, sizeof(result_IP2Location_lib_version), "API=%s Major=%d", IP2Location_api_version_string(), libipv6calc_db_wrapper_IP2Location_library_version_major());
 #else
 	snprintf(result_IP2Location_lib_version, sizeof(result_IP2Location_lib_version), "API=%s Major=%d", IP2LOCATION_API_VERSION, libipv6calc_db_wrapper_IP2Location_library_version_major());
+#endif // SUPPORT_IP2LOCATION_API_VERSION_STRING
 #endif
 
 #ifdef SUPPORT_IP2LOCATION_DYN
@@ -909,7 +941,7 @@ END_libipv6calc_db_wrapper:
 /*
  * wrapper extension: IP2Location_dbfilename
  */
-static char *libipv6calc_db_wrapper_IP2Location_dbfilename(const int type) {
+static char *libipv6calc_db_wrapper_IP2Location_dbfilename(const unsigned int type) {
 	static char tempstring[NI_MAXHOST];
 	int  entry = -1, i;
 
@@ -937,12 +969,12 @@ static char *libipv6calc_db_wrapper_IP2Location_dbfilename(const int type) {
 /*
  * wrapper extension: IP2Location_dbdescription
  */
-const char *libipv6calc_db_wrapper_IP2Location_dbdescription(int type) {
+const char *libipv6calc_db_wrapper_IP2Location_dbdescription(const unsigned int type) {
 	int  entry = -1, i;
 
 	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Called: %s type=%d", wrapper_ip2location_info, type);
 
-	for (i = 0; i < sizeof(libipv6calc_db_wrapper_IP2Location_db_file_desc) / sizeof(libipv6calc_db_wrapper_IP2Location_db_file_desc[0]); i++) {
+	for (i = 0; i < MAXENTRIES_ARRAY(libipv6calc_db_wrapper_IP2Location_db_file_desc); i++) {
 		if (libipv6calc_db_wrapper_IP2Location_db_file_desc[i].number == type) {
 			entry = i;
 			break;
@@ -963,7 +995,7 @@ const char *libipv6calc_db_wrapper_IP2Location_dbdescription(int type) {
  * wrapper extension: IP2Location_db_avail
  * ret: 1=avail  0=not-avail 2=softlink (in case not allowed) 3=softlink (allowed)
  */
-int libipv6calc_db_wrapper_IP2Location_db_avail(int type) {
+int libipv6calc_db_wrapper_IP2Location_db_avail(const unsigned int type) {
 	char *filename;
 	int r, result = 0;
 	IP2Location *loc;
@@ -989,7 +1021,7 @@ int libipv6calc_db_wrapper_IP2Location_db_avail(int type) {
 	};
 
 	if (S_ISLNK(st.st_mode)) {
-		if ((ip2location_db_allow_softlinks == 0)) {
+		if (ip2location_db_allow_softlinks == 0) {
 			DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Finished: %s type=%d (unsupported softlink)", wrapper_ip2location_info, type);
 			result = 2;
 			goto END_libipv6calc_db_wrapper;
@@ -1016,7 +1048,7 @@ END_libipv6calc_db_wrapper:
 /*
  * wrapper extension: IP2Location_open_type
  */
-IP2Location *libipv6calc_db_wrapper_IP2Location_open_type(int type) {
+IP2Location *libipv6calc_db_wrapper_IP2Location_open_type(const unsigned int type) {
 	IP2Location *loc;
 	char *filename;
 	int  entry = -1, i;
@@ -1559,7 +1591,7 @@ char *libipv6calc_db_wrapper_IP2Location_wrapper_country_code_by_addr(char *addr
 	IP2Location *loc;
 	IP2LocationRecord *record;
 
-	int IP2Location_type = 0;
+	unsigned int IP2Location_type = 0;
 	char *IP2Location_result_ptr = NULL;
 
 	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Called with addr=%s proto=%d", addr, proto);
@@ -1648,7 +1680,7 @@ char *libipv6calc_db_wrapper_IP2Location_wrapper_country_name_by_addr(char *addr
 	IP2Location *loc;
 	IP2LocationRecord *record;
 
-	int IP2Location_type = 0;
+	unsigned int IP2Location_type = 0;
 	char *IP2Location_result_ptr = NULL;
 
 	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Called with addr=%s proto=%d", addr, proto);
@@ -1772,20 +1804,27 @@ END_libipv6calc_db_wrapper:
 #endif
 
 /*
- * major library version
+ * major IP2Location library version
  *
  * in : (nothing)
- * out: library version, currently 4, 6, 7
+ * out: major IP2Location library version, currently 4, 6, 7, 8
  */
 int libipv6calc_db_wrapper_IP2Location_library_version_major(void) {
-	int result = 7;
+	int result = 7; // default
 #ifdef SUPPORT_IP2LOCATION_DYN
-	if (ip2location_all_compat != 0) {
-		result = 4;
-	} else if (ip2location_ipv6_compat != 0) {
-		result = 6;
+	if (dl_status_IP2Location_api_version_num == IPV6CALC_DL_STATUS_OK) {
+		result = (*dl_IP2Location_api_version_num.func)() / (100 * 100);
+	} else {
+		if (ip2location_all_compat != 0) {
+			result = 4;
+		} else if (ip2location_ipv6_compat != 0) {
+			result = 6;
+		};
 	};
 #else // SUPPORT_IP2LOCATION_DYN
+#ifdef API_VERSION_MAJOR
+	result = API_VERSION_MAJOR;
+#else // API_VERSION_MAJOR
 #ifdef SUPPORT_IP2LOCATION_ALL_COMPAT
 	result = 4;
 #else // SUPPORT_IP2LOCATION_ALL_COMPAT
@@ -1793,6 +1832,7 @@ int libipv6calc_db_wrapper_IP2Location_library_version_major(void) {
 	result = 6;
 #endif // SUPPORT_IP2LOCATION_IPV6_COMPAT
 #endif // SUPPORT_IP2LOCATION_ALL_COMPAT
+#endif // API_VERSION_MAJOR
 #endif // SUPPORT_IP2LOCATION_DYN
 
 	return(result);
@@ -1805,7 +1845,7 @@ int libipv6calc_db_wrapper_IP2Location_library_version_major(void) {
  * in : database type
  * out: =0:compatible !=0:not compatible
  */
-static int libipv6calc_db_wrapper_IP2Location_db_compatible(const int type) {
+static int libipv6calc_db_wrapper_IP2Location_db_compatible(const unsigned int type) {
 	int result = 0;
 	int i;
 
