@@ -2,7 +2,7 @@
 #
 # Project    : ipv6calc
 # File       : test_ipv6calc_anonymization.sh
-# Version    : $Id: test_ipv6calc_anonymization.sh,v 1.10 2015/06/14 20:14:49 ds6peter Exp $
+# Version    : $Id: 42fbb277ee1990bd521e7f95a5503b3c604ee39e $
 # Copyright  : 2013-2015 by Peter Bieringer <pb (at) bieringer.de>
 #
 # Test ipv6calc anonymization
@@ -216,7 +216,7 @@ run_anon_options_kp_tests() {
 
 		# Check result
 		if [ "$type_orig_compare" != "$type_anon_compare" ]; then
-			echo "ERROR : IPVx_TYPE not equal:"
+			echo "ERROR : IPVx_TYPE not equal: $input"
 			exit 1
 		else
 			[ "$verbose" = "1" ] && echo "Result ok!" || true
@@ -252,7 +252,7 @@ run_anon_options_kp_tests() {
 		else
 			# Check result
 			if [ "$reg_orig" != "$reg_anon" ]; then
-				echo "ERROR : IPVx_REGISTRY not equal:"
+				echo "ERROR : IPVx_REGISTRY not equal: $input"
 				exit 1
 			else
 				[ "$verbose" = "1" ] && echo "Result ok!" || true
