@@ -2,8 +2,9 @@
 #
 # Project    : ipv6calc
 # File       : test_scenarios.sh
-# Version    : $Id: test_scenarios.sh,v 1.50 2015/05/26 17:13:12 ds6peter Exp $
-# Copyright  : 2001-2015 by Peter Bieringer <pb (at) bieringer.de>
+# Version    : $Id: 4ab6783bc4317ab29d77d78baa1224c371694352 $
+# Copyright  : 2001-2016 by Peter Bieringer <pb (at) bieringer.de>
+# License    : GPLv2
 #
 # Test patterns for ipv6calc (functions only)
 
@@ -220,6 +221,24 @@ a909:16fa:9092:23ff:a909:4941::7		anonymized-prefix
 2.2.3.4						ipv4.db.reg=RIPENCC#DB_IPV4_REG
 2.2.3.4						ipv4.db.cc=FR#DB_IPV4_CC
 2.2.3.4						ipv4.db.asn=3215#DB_IPV4_AS
+2.2.3.4						ipv4.addr=le=2.2.3.4
+2.2.3.4						ipv4.addr=lt=2.2.3.5
+2.2.3.4						ipv4.addr=ge=2.2.3.4
+2.2.3.4						ipv4.addr=gt=2.2.3.3
+2001:db8::2					ipv6.addr=le=2001:db8::2
+2001:db8::2					ipv6.addr=lt=2001:db8::3
+2001:db8::2					ipv6.addr=ge=2001:db8::2
+2001:db8::2					ipv6.addr=gt=2001:db8::1
+2001:db8::2					ipv6.addr=gt=2001:db8::1,ipv6.addr=lt=2001:db8::3
+2.2.3.4						ipv4.addr=gt=2.2.3.3,ipv4.addr=lt=2.2.3.5
+2.2.3.4						ipv4.addr=2.2.3.0/24
+2.2.3.4						^ipv4.addr=2.2.2.0/24
+2001:db8::2					ipv6.addr=2001:db8::/32
+2001:db8::2					^ipv6.addr=2001:db9::/32
+2001:db8::2					^ipv6.addr=ge=2001:db8::3
+2001:db8::2					^ipv6.addr=lt=2001:db8::1
+2.2.3.4						^ipv4.addr=gt=2.2.3.5
+2.2.3.4						^ipv4.addr=lt=2.2.3.3
 END
 }
 
@@ -502,3 +521,21 @@ testscenario_hugelist() {
 		;;
 	esac
 }
+
+testscenario_action_test() {
+	# result|options|description
+	cat <<END | grep -v ^#
+0|--test_ge 2001:db8:: --test_le 2001:db8:ffff:ffff:ffff:ffff:ffff:ffff 2001:db8::1
+1|--test_ge 2001:db9:: --test_le 2001:db9:ffff:ffff:ffff:ffff:ffff:ffff 2001:db8::1
+1|--test_ge 2001:db9:: --test_lt 2001:dba:: 2001:db8::1
+0|--test_ge 2001:db8:: --test_lt 2001:db9:: 2001:db8::1
+1|--test_gt 2001:db8::1 --test_lt 2001:db9:: 2001:db8::1
+0|--test_ge 2001:db8::1 --test_lt 2001:db9:: 2001:db8::1
+1|--test_gt 2001:db8::1 --test_lt 2001:db9::1 2001:db9::1
+0|--test_ge 2001:db8::1 --test_le 2001:db9::1 2001:db9::1
+0|--test_ge 1.2.3.0 --test_lt 1.2.3.5 1.2.3.0
+1|--test_ge 1.2.3.0 --test_lt 1.2.3.5 1.2.3.5
+0|--test_ge 1.2.3.0 --test_le 1.2.3.5 1.2.3.5
+1|--test_ge 1.2.3.1 --test_le 1.2.3.5 1.2.3.0
+END
+}
