@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6loganon.c
- * Version    : $Id: ipv6loganon.c,v 1.38 2015/05/26 15:50:04 ds6peter Exp $
- * Copyright  : 2007-2015 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: 61b55bf8c7dbe2504b86f4e1d6f7dec071063680 $
+ * Copyright  : 2007-2016 by Peter Bieringer <pb (at) bieringer.de>
  * 
  * Information:
  *  Dedicated program for logfile anonymization
@@ -400,7 +400,7 @@ static void lineparser(void) {
  * Anonymize token
  */
 static int anonymizetoken(char *resultstring, const size_t resultstring_length, const char *token) {
-	long int inputtype = -1;
+	uint32_t inputtype = FORMAT_undefined;
 	int retval = 1, i;
 
 	/* used structures */
@@ -462,7 +462,7 @@ static int anonymizetoken(char *resultstring, const size_t resultstring_length,
 	inputtype = libipv6calc_autodetectinput(token);
 
 	DEBUGSECTION_BEGIN(DEBUG_ipv6loganon_general)
-		if (inputtype >= 0) {
+		if (inputtype != FORMAT_undefined) {
 			for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_formatstrings); i++) {
 				if (inputtype == ipv6calc_formatstrings[i].number) {
 					DEBUGPRINT_WA(DEBUG_ipv6loganon_general, "Found type: %s", ipv6calc_formatstrings[i].token);
