@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6logconv.c
- * Version    : $Id: ipv6logconv.c,v 1.41 2015/05/26 15:50:04 ds6peter Exp $
- * Copyright  : 2002-2015 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: 59d88133eac2042cf582469427384e5f60b57856 $
+ * Copyright  : 2002-2016 by Peter Bieringer <pb (at) bieringer.de>
  * 
  * Information:
  *  Dedicated program for logfile conversions
@@ -395,7 +395,7 @@ END_line:
  * Convert token
  */
 static int converttoken(char *resultstring, const size_t resultstring_length, const char *token, const long int outputtype, const int flag_skipunknown) {
-	long int inputtype = -1;
+	uint32_t inputtype = FORMAT_undefined;
 	int retval = 1, i, registry;
 	uint32_t typeinfo, typeinfo_test;
 	char tempstring[NI_MAXHOST];
@@ -465,7 +465,7 @@ static int converttoken(char *resultstring, const size_t resultstring_length, co
 	inputtype = libipv6calc_autodetectinput(token);
 
 	DEBUGSECTION_BEGIN(DEBUG_ipv6logconv_processing)
-		if (inputtype >= 0) {
+		if (inputtype != FORMAT_undefined) {
 			for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_formatstrings); i++) {
 				if (inputtype == ipv6calc_formatstrings[i].number) {
 					DEBUGPRINT_WA(DEBUG_ipv6logconv_processing, "Found type: %s", ipv6calc_formatstrings[i].token);
