@@ -1,8 +1,9 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6calccommands.h
- * Version    : $Id: ipv6calccommands.h,v 1.25 2015/05/26 15:50:04 ds6peter Exp $
- * Copyright  : 2002-2014 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: 53f972e0000306d0228433f92b4b74d66c85608d $
+ * Copyright  : 2002-2016 by Peter Bieringer <pb (at) bieringer.de>
+ * License    : GPLv2
  *
  * Information:
  *  Header file containing commands for ipv6calc
@@ -103,4 +104,11 @@
 #define CMD_6rd_relay_prefix		0x0004002
 #define CMD_6rd_prefixlength		0x0004003
 
+/* address test options */
+#define CMD_test_prefix			0x0005001	// prefix
+#define CMD_test_gt			0x0005002	// greater than
+#define CMD_test_ge			0x0005003	// greater equal
+#define CMD_test_lt			0x0005004	// less than
+#define CMD_test_le			0x0005005	// less equal
+
 #endif
