@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6calchelp.c
- * Version    : $Id: ipv6calchelp.c,v 1.82 2015/08/23 09:53:27 ds6peter Exp $
- * Copyright  : 2002-2015 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: f6d90fc38c790d9ee526e7725855b71250897e7c $
+ * Copyright  : 2002-2016 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  Help library
@@ -269,7 +269,7 @@ void printhelp_actiontypes(const uint32_t formatoptions, const struct option lon
 						/* run through options */
 						o = 0;
 						while(longopts[o].name != NULL) {
-							if ((ipv6calc_actionoptionmap[i][1] == longopts[o].val)) {
+							if ((ipv6calc_actionoptionmap[i][1] == (uint32_t) longopts[o].val)) {
 								has_options = 1;
 								if (test == 1) {	
 									fprintf(stderr, printformatstring3, "", longopts[o].name);
@@ -702,7 +702,7 @@ void printhelp_action_dispatcher(const uint32_t action, const int embedded) {
 			fprintf(stderr, "   --anonymize-paranoid\n");
 			fprintf(stderr, "\n");
 			fprintf(stderr, "  Supported methods [--anonymize-method METHOD]:\n");
-			for (i = 0; i < sizeof(ipv6calc_anon_methods) / sizeof(s_ipv6calc_anon_methods); i++) {
+			for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_anon_methods); i++) {
 				fprintf(stderr, "   %-10s: %s\n", ipv6calc_anon_methods[i].name, ipv6calc_anon_methods[i].description);
 			};
 			fprintf(stderr, "\n");
@@ -712,7 +712,7 @@ void printhelp_action_dispatcher(const uint32_t action, const int embedded) {
 			for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_anon_set_list); i++) {
 				snprintf(method_name, sizeof(method_name), "%s", "unknown"); // default
 
-				for (j = 0; j < sizeof(ipv6calc_anon_methods) / sizeof(s_ipv6calc_anon_methods); j++) {
+				for (j = 0; j < MAXENTRIES_ARRAY(ipv6calc_anon_methods); j++) {
 					if (ipv6calc_anon_methods[j].method == ipv6calc_anon_set_list[i].method) {
 						snprintf(method_name, sizeof(method_name), "%s", ipv6calc_anon_methods[j].name);
 						break;
@@ -745,7 +745,7 @@ void printhelp_action_dispatcher(const uint32_t action, const int embedded) {
 			break;
 
 		case ACTION_filter:
-			fprintf(stderr, " Filter given addresses from stdout by filter expression, e.g.\n");
+			fprintf(stderr, " Filter given addresses from stdin by filter expression, e.g.\n");
 			fprintf(stderr, "  echo '2001:db8::1' | ipv6calc [-A filter] -E iid-local\n");
 			fprintf(stderr, "  echo '2001:db8::1' | ipv6calc [-A filter] -E iid-local,global-unicast\n");
 			fprintf(stderr, "  echo '2001:db8::1' | ipv6calc [-A filter] -E ^iid-random\n");
@@ -782,6 +782,14 @@ void printhelp_action_dispatcher(const uint32_t action, const int embedded) {
 			fprintf(stderr, "   [^]ipv4.addr=<IPV4-ADDRESS>[<PREFIX-LENGTH>]\n");
 			fprintf(stderr, "   [^]ipv6.addr=<IPV6-ADDRESS>[<PREFIX-LENGTH>]\n");
 			fprintf(stderr, "\n");
+			fprintf(stderr, "  IPv4/v6 address filter tokens based on address ranges (<=|<|>|>=):\n");
+			fprintf(stderr, "   [^]ipv4.addr(<=|<|>|>=)<IPV4-ADDRESS>\n");
+			fprintf(stderr, "   [^]ipv6.addr(<=|<|>|>=)<IPV6-ADDRESS>\n");
+			fprintf(stderr, "\n");
+			fprintf(stderr, "   as alternative in case <|> creating problems also supported: =(le|lt|gt|ge)=:\n");
+			fprintf(stderr, "   [^]ipv4.addr=(le|lt|gt|ge)=<IPV4-ADDRESS>\n");
+			fprintf(stderr, "   [^]ipv6.addr=(le|lt|gt|ge)=<IPV6-ADDRESS>\n");
+			fprintf(stderr, "\n");
 			fprintf(stderr, "  EUI-48/MAC address filter tokens:\n");
 			fprintf(stderr, "   ");
 			fprintf(stderr, " IMPLEMENTATION MISSING");
@@ -792,6 +800,26 @@ void printhelp_action_dispatcher(const uint32_t action, const int embedded) {
 			fprintf(stderr, " IMPLEMENTATION MISSING");
 			fprintf(stderr, "\n");
 			break;
+
+		case ACTION_test:
+			fprintf(stderr, " Test given address(es) against supported tests:\n");
+			fprintf(stderr, "  --test_prefix <PREFIX>       : inside a prefix\n");
+			fprintf(stderr, "  --test_gt|--test_ge <ADDRESS>: greater(/equal) than an address\n");
+			fprintf(stderr, "  --test_lt|--test_le <ADDRESS>: less(/equal) than an address\n");
+			fprintf(stderr, "\n");
+			fprintf(stderr, " Test given address(es) from stdin, e.g.\n");
+			fprintf(stderr, "  echo '2001:db8::1' | ipv6calc [-A test] --test_prefix 2001:db8::/32\n");
+			fprintf(stderr, "  echo '2001:db8::1' | ipv6calc [-A test] --test_prefix 2001:db9::/32\n");
+			fprintf(stderr, "\n");
+			fprintf(stderr, " Single address test, return code: 0=inside/matching 1=outside/not-matching 2=uncomparable\n");
+			fprintf(stderr, "  ipv6calc [-A test] --test_prefix 2001:db8::/32 2001:db8::1\n");
+			fprintf(stderr, "  ipv6calc [-A test] --test_prefix 2001:db9::/32 2001:db8::1\n");
+			fprintf(stderr, "  ipv6calc [-A test] --test_ge 2001:db8:: --test_le 2001:db8:ffff:ffff:ffff:ffff:ffff:ffff 2001:db8::1\n");
+			fprintf(stderr, "  ipv6calc [-A test] --test_ge 2001:db9:: --test_le 2001:db9:ffff:ffff:ffff:ffff:ffff:ffff 2001:db8::1\n");
+			fprintf(stderr, "  ipv6calc [-A test] --test_ge 2001:db9:: --test_lt 2001:dba:: 2001:db8::1\n");
+			fprintf(stderr, "  ipv6calc [-A test] --test_ge 2001:db8:: --test_lt 2001:db9:: 2001:db8::1\n");
+			fprintf(stderr, "\n");
+			break;
 	};
 };
 
@@ -883,7 +911,11 @@ void ipv6calc_print_features_verbose(const int level_verbose) {
 #ifdef IP2LOCATION_INCLUDE_VERSION
 	fprintf(stderr, "IP2Location support enabled, compiled with include file version: %s\n", IP2LOCATION_INCLUDE_VERSION);
 #endif
-	fprintf(stderr, "IP2Location support enabled, compiled with API version: %s\n", xmakestr(API_VERSION));
+#if SUPPORT_IP2LOCATION_API_VERSION_STRING
+	fprintf(stderr, "IP2Location support enabled, compiled with API version: %s, dynamically linked with version: %s\n", xmakestr(API_VERSION), libipv6calc_db_wrapper_IP2Location_lib_version());
+#else
+	fprintf(stderr, "IP2Location support enabled, compiled with API version: %s (linked version not supported)\n", xmakestr(API_VERSION));
+#endif // SUPPORT_IP2LOCATION_API_VERSION_STRING
 #ifndef SUPPORT_IP2LOCATION_DYN
 #else
 	fprintf(stderr, "IP2Location support by dynamic library load\n");
